# ChatGPT TUI

![](https://i.imgur.com/E1mrVGU.png)

`catt` is a Python-based Text User Interface (TUI) for ChatGPT, powered by OpenAI's official API. It provides an easy-to-use interface that allows you to interact with ChatGPT directly from your terminal.

## Usage

### Install

```bash
pip install chatgpt_tui
```

### Export your OpenAI API key

Before using it, you need to export your [OpenAI API key](https://platform.openai.com/account/api-keys) as an environment variable:

```bash
export OPENAI_API_KEY=your-api-key
```

### Launch

To start the app, simply run the following command in your terminal:

```bash
catt
```

This will launch `catt` and connect you to the ChatGPT chatbot.

### Road Map
- Resume from previous chat history
- Improve UI/UX
  - Better visuals
  - More keybindings

# License

`catt` is licensed under the MIT License.
